/*
 * jQuery Media Plugin for converting elements into rich media content.
 *
 * Examples and documentation at: http://malsup.com/jquery/media/
 * Copyright (c) 2007-2010 M. Alsup
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 * @author: M. Alsup
 * @version: 0.97 (20-MAY-2011)
 * @requires jQuery v1.1.2 or later
 * $Id: jquery.media.js 2460 2007-07-23 02:53:15Z malsup $
 *
 * Supported Media Players:
 *	- Flash
 *	- Quicktime
 *	- Real Player
 *	- Silverlight
 *	- Windows Media Player
 *	- iframe
 *
 * Supported Media Formats:
 *	 Any types supported by the above players, such as:
 *	 Video: asf, avi, flv, mov, mpg, mpeg, mp4, qt, smil, swf, wmv, 3g2, 3gp
 *	 Audio: aif, aac, au, gsm, mid, midi, mov, mp3, m4a, snd, rm, wav, wma
 *	 Other: bmp, html, pdf, psd, qif, qtif, qti, tif, tiff, xaml
 *
 * Thanks to Mark Hicken and Brent Pedersen for helping me debug this on the Mac!
 * Thanks to Dan Rossi for numerous bug reports and code bits!
 * Thanks to Skye Giordano for several great suggestions!
 * Thanks to Richard Connamacher for excellent improvements to the non-IE behavior!
 */
;(function($) {

var lameIE = $.browser.msie && $.browser.version < 9;


/**
 * Chainable method for converting elements into rich media.
 *
 * @param options
 * @param callback fn invoked for each matched element before conversion
 * @param callback fn invoked for each matched element after conversion
 */
$.fn.media = function(options, f1, f2) {
	if (options == 'undo') {
		return this.each(function() {
			var $this = $(this);
			var html = $this.data('media-orightml');
			if (html) {
				$this.replaceWith(html);
			}
		});
	}
	
	return this.each(function() {
		if (typeof options == 'function') {
			f2 = f1;
			f1 = options;
			options = {};
		}
		
		var o = $.fn.media.getSettings(this, options);
		// pre-conversion callback, passes original element and fully populated options
		if (typeof f1 == 'function') f1(this, o);

		var r = getTypesRegExp();
		var m = r.exec(o.src.toLowerCase()) || [''];

		o.type ? m[0] = o.type : m.shift();
		for (var i=0; i < m.length; i++) {
			fn = m[i].toLowerCase();
			if (isDigit(fn[0])) fn = 'fn' + fn; // fns can't begin with numbers
			if (!$.fn.media[fn])
				continue;  // unrecognized media type
			// normalize autoplay settings
			var player = $.fn.media[fn+'_player'];
			if (!o.params) o.params = {};
			if (player) {
				var num = player.autoplayAttr == 'autostart';
				o.params[player.autoplayAttr || 'autoplay'] = num ? (o.autoplay ? 1 : 0) : o.autoplay ? true : false;
			}
			var $div = $.fn.media[fn](this, o);
			
			//'margin': 'auto'
			$div.css({'backgroundColor': o.bgColor}).width(o.width).height(o.height);
			
			var $this = $(this);
			var aClasses = $this.attr("class");
			if (aClasses) {
				$(aClasses.split(' ')).each(function() { 
					if (this !== '' && ""+this !== "media") {
						$($div).addClass(""+this);
					}
				});
			}
			
			$("img.still", $div).width(o.width).height(o.height);
			
			if ($("#videoContainer", $div).length > 0) {
				$("#videoContainer", $div).width(o.width).height(o.height+50);
				$div.height(o.height+50);
			}
			
			if (dams3PresentationMode) {
				o.canUndo = false;
			}
			
			if (o.canUndo) {
				var $temp = $('<div></div>').append(this);
				$div.attr('data-media-orightml', $temp.html()); // store original markup
			}
			
			// post-conversion callback, passes original element, new div element and fully populated options
			if (typeof f2 == 'function') f2(this, $div[0], o, player.name);
			break;
		}
	});
};

/**
 * Non-chainable method for adding or changing file format / player mapping
 * @name mapFormat
 * @param String format File format extension (ie: mov, wav, mp3)
 * @param String player Player name to use for the format (one of: flash, quicktime, realplayer, winmedia, silverlight or iframe
 */
$.fn.media.mapFormat = function(format, player) {
	if (!format || !player || !$.fn.media.defaults.players[player]) return; // invalid
	format = format.toLowerCase();
	if (isDigit(format[0])) format = 'fn' + format;
	$.fn.media[format] = $.fn.media[player];
	$.fn.media[format+'_player'] = $.fn.media.defaults.players[player];
};

// global defautls; override as needed
$.fn.media.defaults = {
	standards:  true,       // use object tags only (no embeds for non-IE browsers)
	canUndo:    true,       // tells plugin to store the original markup so it can be reverted via: $(sel).mediaUndo()
	width:		700,
	height:		400,
	autoplay:	0,		   	// normalized cross-player setting
	bgColor:	'#ffffff', 	// background color
	params:		{ wmode: 'transparent'},	// added to object element as param elements; added to embed element as attrs
	attrs:		{},			// added to object and embed elements as attrs
	flvKeyName: 'file', 	// key used for object src param (thanks to Andrea Ercolino)
	flashvars:	{},			// added to flash content as flashvars param/attr
	flashVersion:	'7',	// required flash version
	expressInstaller: null,	// src for express installer

	// default flash video and mp3 player (@see: http://jeroenwijering.com/?item=Flash_Media_Player)
	flvPlayer:	 'mediaplayer.swf',
	mp3Player:	 'mediaplayer.swf',

	// @see http://msdn2.microsoft.com/en-us/library/bb412401.aspx
	silverlight: {
		inplaceInstallPrompt: 'true', // display in-place install prompt?
		isWindowless:		  'true', // windowless mode (false for wrapping markup)
		framerate:			  '24',	  // maximum framerate
		version:			  '0.9',  // Silverlight version
		onError:			  null,	  // onError callback
		onLoad:			      null,   // onLoad callback
		initParams:			  null,	  // object init params
		userContext:		  null	  // callback arg passed to the load callback
	}
};

// Media Players; think twice before overriding
$.fn.media.defaults.players = {
	flash: {
		name:		 'flash',
		title:		 'Flash',
		types:		 'flv,mp3,swf',
		mimetype:	 'application/x-shockwave-flash',
		pluginspage: 'http://www.adobe.com/go/getflashplayer',
		ieAttrs: {
			classid:  'clsid:d27cdb6e-ae6d-11cf-96b8-444553540000',
			type:	  'application/x-oleobject',
			codebase: 'http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=' + $.fn.media.defaults.flashVersion
		}
	},
	quicktime: {
		name:		 'quicktime',
		title:		 'QuickTime',
		mimetype:	 'video/quicktime',
		pluginspage: 'http://www.apple.com/quicktime/download/',
		types:		 'aif,aiff,aac,au,bmp,gsm,mov,mid,midi,mpg,mpeg,mp4,m4a,psd,qt,qtif,qif,qti,snd,tif,tiff,wav,3g2,3gp',
		ieAttrs: {
			classid:  'clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B',
			codebase: 'http://www.apple.com/qtactivex/qtplugin.cab'
		}
	},
	realplayer: {
		name:		  'real',
		title:		  'RealPlayer',
		types:		  'ra,ram,rm,rpm,rv,smi,smil',
		mimetype:	  'audio/x-pn-realaudio-plugin',
		pluginspage:  'http://www.real.com/player/',
		autoplayAttr: 'autostart',
		ieAttrs: {
			classid: 'clsid:CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA'
		}
	},
	winmedia: {
		name:		  'winmedia',
		title:		  'Windows Media',
		types:		  'asx,asf,avi,wma,wmv',
		mimetype:	  $.browser.mozilla && isFirefoxWMPPluginInstalled() ? 'application/x-ms-wmp' : 'application/x-mplayer2',
		pluginspage:  'http://www.microsoft.com/Windows/MediaPlayer/',
		autoplayAttr: 'autostart',
		oUrl:		  'url',
		ieAttrs: {
			classid:  'clsid:6BF52A52-394A-11d3-B153-00C04F79FAA6',
			type:	  'application/x-oleobject'
		}
	},
	// special cases
	img: {
		name:  'img',
		title: 'Image',
		types: 'gif,png,jpg'
	},
	iframe: {
		name:  'iframe',
		types: 'html,pdf'
	},
	silverlight: {
		name:  'silverlight',
		types: 'xaml'
	},
	flowplayer: {
		name:		 'flowplayer',
		title:		 'FlowPlayer',
		types:		 'm4v, mp4',
		scale:		 false,
		lightbox:	 true
	}
};

// everything below here is private
// detection script for FF WMP plugin (http://www.therossman.org/experiments/wmp_play.html)
// (hat tip to Mark Ross for this script)
function isFirefoxWMPPluginInstalled() {
	var plugs = navigator.plugins;
	for (var i = 0; i < plugs.length; i++) {
		var plugin = plugs[i];
		if (plugin['filename'] == 'np-mswmp.dll')
			return true;
	}
	return false;
}

var counter = 1;

for (var player in $.fn.media.defaults.players) {
	var types = $.fn.media.defaults.players[player].types;
	$.each(types.split(','), function(i,o) {
		if (isDigit(o[0])) o = 'fn' + o;
		$.fn.media[o] = $.fn.media[player] = getGenerator(player);
		$.fn.media[o+'_player'] = $.fn.media.defaults.players[player];
	});
};

function getTypesRegExp() {
	var types = '';
	for (var player in $.fn.media.defaults.players) {
		if (types.length) types += ',';
		types += $.fn.media.defaults.players[player].types;
	};
	return new RegExp('\\.(' + types.replace(/,/ig,'|') + ')\\b');
};

function getGenerator(player) {
	return function(el, options) {
		return generate(el, options, player);
	};
};

function isDigit(c) {
	return '0123456789'.indexOf(c) > -1;
};

// flatten all possible options: global defaults, meta, option obj
$.fn.media.getSettings = function(el, options) {
	options = options || {};
	var $el = $(el).first();
	var meta = $el.data('media') || {};

	var a = $.fn.media.defaults;
	var b = options;
	var c = meta;

	var p = { params: { bgColor: options.bgColor || $.fn.media.defaults.bgColor } };
	var opts = $.extend({}, a, b, c);
	$.each(['attrs','params','flashvars','silverlight'], function(i,o) {
		opts[o] = $.extend({}, p[o] || {}, a[o] || {}, b[o] || {}, c[o] || {});
	});

	// if (typeof opts.caption == 'undefined') opts.caption = $el.text();

	// make sure we have a source!
	opts.src = opts.src || $el.attr('href') || $el.attr('src') || 'unknown';
	if (!opts.still && $('img.still', $el).length > 0) {
		opts.still = $('img.still', $el).first().attr('src');
	}
	
	return opts;
};

//
//	Flash Player
//

// generate flash using SWFObject library if possible
$.fn.media.swf = function(el, opts) {
	if (!window.SWFObject && !window.swfobject) {
		// roll our own
		if (opts.flashvars) {
			var a = [];
			for (var f in opts.flashvars)
				a.push(f + '=' + opts.flashvars[f]);
			if (!opts.params) opts.params = {};
			opts.params.flashvars = a.join('&');
		}
		return generate(el, opts, 'flash');
	}

	var id = el.id ? (' id="'+el.id+'"') : '';
	var cls = opts.cls ? (' data-media="' + opts.cls + '"') : '';
	var $div = $('<div' + id + cls + '>');

	// swfobject v2+
	if (window.swfobject) {
		$(el).after($div).appendTo($div);
		if (!el.id) el.id = 'movie_player_' + counter++;

		// replace el with swfobject content
		swfobject.embedSWF(opts.src, el.id, opts.width, opts.height, opts.flashVersion,
			opts.expressInstaller, opts.flashvars, opts.params, opts.attrs);
	}
	// swfobject < v2
	else {
		$(el).after($div).remove();
		var so = new SWFObject(opts.src, 'movie_player_' + counter++, opts.width, opts.height, opts.flashVersion, opts.bgColor);
		if (opts.expressInstaller) so.useExpressInstall(opts.expressInstaller);

		for (var p in opts.params)
			if (p != 'bgColor') so.addParam(p, opts.params[p]);
		for (var f in opts.flashvars)
			so.addVariable(f, opts.flashvars[f]);
		so.write($div[0]);
	}

	if (opts.caption) $('<div>').appendTo($div).html(opts.caption);
	return $div;
};

// map flv and mp3 files to the swf player by default
$.fn.media.flv = $.fn.media.mp3 = function(el, opts) {
	var src = opts.src;
	var player = /\.mp3\b/i.test(src) ? opts.mp3Player : opts.flvPlayer;
	var key = opts.flvKeyName;
	src = encodeURIComponent(src);
	opts.src = player;
	opts.src = opts.src + '?'+key+'=' + (src);
	var srcObj = {};
	srcObj[key] = src;
	opts.flashvars = $.extend({}, srcObj, opts.flashvars );
	return $.fn.media.swf(el, opts);
};

$.fn.media.m4v = $.fn.media.mp4 = function(el, opts) {

	var options = opts.players['flowplayer'];
	options.lightbox = false;
	options.scale = false;
	options.baseVideoUrl = Dams.siteUrl;
	
	var layoutResourcesFolder = Dams.siteUrl + 'layoutSubSite/';
	var flowbase = layoutResourcesFolder + 'js/flowplayer/';
	
	var jsControlsOptions = {
		template: '<a class="play">play</a>' + 
			'<div class="time"></div>' +
			'<div class="track">' +
				'<div class="buffer"></div>' +
				'<div class="progress"></div>' +
				'<div class="playhead"></div>' +
			'</div>' + 
			'<a class="mute">mute</a>'
	}

	var video = document.createElement("video");
	var canPlayMp4 = (typeof video.canPlayType === 'function' && !!video.canPlayType('video/mp4; codecs="avc1.42E01E, mp4a.40.2"').replace(/no/, ''));
	if ($.browser.mozilla)
		canPlayMp4 = false;
	//var noflash = flashembed.getVersion()[0] === 0;
	var idevice = /ip(hone|ad|od)/i.test(navigator.userAgent);
	var android = /android/i.test(navigator.userAgent);
	jQuery(video).detach();
		
	//var	useVideoTag = !idevice &&  noflash &&  canPlayMp4;
	var	useVideoTag = !idevice && canPlayMp4;

	var damVideoRenditions = {
		'720p': {
					width: 1280,
					height: 720,
					bitrate: 1150,
					name: '720p',
					hd: true
				},
		'480p': {
					width: 853,
					height: 480,
					bitrate: 550,
					name: '480p'
				},
		'360p': {
					width: 640,
					height: 360,
					bitrate: 300,
					name: '360p'
				},
		'240p': {
					width: 426,
					height: 240,
					bitrate: 200,
					name: '240p'
				}
	};

	if (!Dams.video) {
		Dams.video = {};
		Dams.video.defaultQuality = '480p';
		Dams.video.flashDebug = false;
		Dams.video.jsControls = true;
		Dams.video.addPlayOverlay = true;
		Dams.video.streaming = false;
	}

	var _getMaxDimensions = function(clips, reservedWidth, reservedHeight, forcedSize) {

		var width;
		var height;
		
		if (forcedSize) {
			width = height = forcedSize
		} else if (options.lightbox) {
			width = jQuery(window).width() - reservedWidth;
			height = jQuery(window).height() - reservedHeight;
		} else {
			width = reservedWidth;
			height = reservedHeight;
		}
		
		var clip;
		for(var key in clips){
			clip = (clips[key]);
			break;
		}
		
		var ratio = clip.width / clip.height;
		
		var max = (width/height > ratio ? height * ratio : width);
		if (max > 1280) max = 1280;
		
		//_log(width/height > ratio);
		//_log(max);
		
		var maxWidth = Math.round(max);
		var maxHeight = Math.round(maxWidth / ratio);
		
		//_log('viewport: ' + width + ', ' + height + ' => ' + max + ', ' +  maxWidth + ', ' + maxHeight + ', ' + ratio);
		
		var smallestClip, bestFitClip;
		for(var key in clips){
			if (smallestClip == null || clips[key].height < smallestClip.height);
				smallestClip = clips[key];
			if (clips[key].height <= maxHeight && (bestFitClip == null || clips[key].height > bestFitClip.height))
				bestFitClip = clips[key];
		}
		
		if (bestFitClip == null)
			bestFitClip = smallestClip;
		
		return {
			'maxWidth': maxWidth,
			'maxHeight': maxHeight,
			'clip': bestFitClip,
			'width': bestFitClip.width,
			'height': bestFitClip.height
		};
	};
	
	var _log = function(message) {
		window.console && console.log(message);
	}

	var playHolder = $("<div></div>").addClass('playHolder');

	var stillSrc = $("img.still", el).attr("src");
	if (stillSrc) {
		options.lightbox = true;
		var stillImg = $("<img src='" + stillSrc + "' class='still'/>")
		$(playHolder).append(stillImg);
		if (Dams.video.addPlayOverlay) {
			$(playHolder).append('<img class="playOverlay" src="' + layoutResourcesFolder + 'images/video_play_overlay.png" />');
		}
	}
	
	var videoSrc = $(el).attr("href");

	var testdiv = $('<div></div>');
	$("#contentContainer").append(testdiv);
	$(el).after(playHolder).remove();

	if (!videoSrc) {
		return playHolder;
	}
	
	if (videoSrc.indexOf('://') == -1) {
		if (options.baseVideoUrl) {
			videoSrc = options.baseVideoUrl + videoSrc;
		} else {
			if (window.location.pathname.charAt(window.location.pathname.length - 1) == '/') {
				videoSrc = window.location.href + videoSrc;
			} else {
				var parts = window.location.href.split('/');
				parts.pop();
				videoSrc = parts.join('/') + '/' + videoSrc;
			}
		}
	}

	var bitrates = [];
	
	var parts = videoSrc.split('.');
	var extension = parts.pop()
	var baseVideo = parts.join('.');
	//_log('baseVideo: ' + baseVideo + ', extension: ' + extension);

	for(var key in damVideoRenditions){
		bitrates.push(damVideoRenditions[key]);
		if (key == Dams.video.defaultQuality)
			damVideoRenditions[key].isDefault = true;
			damVideoRenditions[key].url = baseVideo + '_' + key + '.' + extension;
 	}

	var plugins = {};
	

	plugins.bwcheck = {  
		url: flowbase + 'flowplayer.bwcheck-3.2.9.swf',
		netConnectionUrl: flowbase + '100k.jpg',
		checkOnStart: true,
		serverType: 'http',
		onBwDone: function(info, detectedBitrate) {
				//_log('bitrate: ' + detectedBitrate);
		}
	}

	if (Dams.video.jsControls) {
		plugins.controls = null;
	} else {
		plugins.controls = {
			url: flowbase + 'flowplayer.controls-3.2.10.swf',
			
			backgroundColor: "transparent",
			backgroundGradient: "none",
			sliderColor: '#FFFFFF',
			sliderBorder: '1.5px solid rgba(160,160,160,0.7)',
			volumeSliderColor: '#FFFFFF',
			volumeBorder: '1.5px solid rgba(160,160,160,0.7)',

			timeColor: '#ffffff',
			durationColor: '#535353',

			tooltipColor: 'rgba(255, 255, 255, 0.7)',
			tooltipTextColor: '#000000'
		}
	}
	
	var clip = {
		url: damVideoRenditions[Dams.video.defaultQuality].url,
		autoPlay: false,
		urlResolvers: useVideoTag ? null : 'bwcheck',
		accelerated: true,
		scaling: 'fit',
		bitrates: bitrates,
		onStart: function(clip) {
			//console && console.log(clip.index);
		},
		onError: function(errorMessage, errorCode) {
				//_log('ClipError: ' + errorMessage);
		},
		onFinish: function() {
			if (options.lightbox) {
				$.fancybox.close();
			}
		}
	}

	if (options.lightbox) {
	
		playHolder.click(function(event) {
			event.preventDefault();
			
			if (idevice) {
			
				var maxSize = (jQuery(window).height() > jQuery(window).width()) ? jQuery(window).height() : jQuery(window).width();
				if (idevice && maxSize > 1000)
					maxSize = 1280;

				var dimensions = _getMaxDimensions(damVideoRenditions, 0, 0, maxSize);
		
				window.location.href = dimensions.clip.url;

			} else {

				jQuery('#videoTempContainer').remove();
				var videoTempContainer = jQuery('<div id="videoTempContainer"></div>');
				var videoWrapper = jQuery('<div id="videoWrapper" class="playerWrapper"></div>').appendTo(videoTempContainer);
				var videoPlayerWrapper = jQuery('<div id="videoPlayerWrapper"><span>&nbsp;</span></div>').appendTo(videoWrapper);
				var controls = jQuery('<div id="controls" class="jscontrols">' +
					'<a class="play">play</a>' + 
					'<div class="time"></div>' +
					'<div class="track"><div class="buffer"></div><div class="progress"></div><div class="playhead"></div></div>' + 
					'<a class="mute">mute</a></div>').appendTo(videoWrapper);
				var videoPlayer;
				videoTempContainer.appendTo('body');
		
				$.fancybox({
					orig : this,
					padding : 15,
					transitionIn : 'none',
					transitionOut : 'none',
					autoDimensions: true,
					href: '#videoWrapper',
					onStart: function() {
						var dimensions = _getMaxDimensions(damVideoRenditions, (this.margin + this.padding) * 2, (this.margin + this.padding) * 2 + controls.height());
						var videoHeight, videoWidth;
						if (options.scale) {
							videoHeight = dimensions.maxHeight;
							videoWidth = dimensions.maxWidth;
						} else {
							videoHeight = dimensions.height;
							videoWidth = dimensions.width;
						}
						$(videoPlayerWrapper).width(videoWidth + 'px').height(videoHeight + 'px');
						$(videoWrapper).height(videoHeight + controls.height() + 'px').width(videoWidth + 'px');
						plugins.bwcheck.maxWidth = videoWidth;

						clip.url = dimensions.clip.url; 
						clip.autoBuffering = true;
						// until we sole the problem
						clip.urlResolvers = null;


						$(videoPlayerWrapper).flowplayer(
							'/globalLayout/js/flowplayer/flowplayer-3.2.10.swf',
							//"http://releases.flowplayer.org/swf/flowplayer-3.2.10.swf",
							//flowbase + 'flowplayer-3.2.10.swf', 
							{
								clip: clip,
								plugins: plugins,
								screen:  {
									 backgroundColor: '#ffffff'

								},
								canvas:  {
									 backgroundColor: '#ffffff'

								},
								debug: false,
								/*log : {
									level  : 'info',
									filter : 'org.flowplayer.*'
								},*/
								dummy: true
							}
						);
						videoPlayer = videoPlayerWrapper.flowplayer(0).ipad({ simulateiDevice: useVideoTag, controls: false });
						if (!videoPlayer.isLoaded()) {
							videoPlayer.load();
						}
					},
					onComplete: function() {
						var offset = controls.find('.time').width();
						offset += controls.find('.play').width();
						controls.find('.track').width(videoPlayerWrapper.width() - offset - 35);
						videoPlayer.controls('controls');
						!idevice && videoPlayer.play();
					},
					onCleanup : function() {
						//_log('cleanup');
						videoPlayer.stop();
						videoPlayer.unload();
					},
					onClosed: function() {
						//_log('closed');
						videoTempContainer.hide();
						videoTempContainer.remove();
					},
					onCancel : function() {
						//_log('cancel');
					},
					onError : function() {
						//_log('error');
					}

				});
			}

		});
	
	} else {
		
		var videoContainer = jQuery('<div id="videoContainer"></div>');
		var videoWrapper = jQuery('<div id="videoWrapper" class="playerWrapper"></div>').appendTo(videoContainer);
		var videoPlayerWrapper = jQuery('<div id="videoPlayerWrapper"></div>').appendTo(videoWrapper);
		var controls = jQuery('<div id="controls" class="jscontrols">' +
					'<a class="play">play</a>' + 
					'<div class="time"></div>' +
					'<div class="track"><div class="buffer"></div><div class="progress"></div><div class="playhead"></div></div>' + 
					'<a class="mute">mute</a></div>').appendTo(videoWrapper);
		var videoPlayer;
		$(playHolder).append(videoContainer);

		var dimensions = _getMaxDimensions(damVideoRenditions, opts.width, opts.height + controls.height());
		var videoHeight, videoWidth;
		if (options.scale) {
			videoHeight = dimensions.maxHeight;
			videoWidth = dimensions.maxWidth;
		} else {
			videoHeight = dimensions.height;
			videoWidth = dimensions.width;
		}
		videoPlayerWrapper.width(opts.width + 'px').height(opts.height + 'px');
		videoWrapper.height(opts.height + controls.height() + 'px').width(opts.width + 'px');
		plugins.bwcheck.maxWidth = opts.width;
		clip.url = dimensions.clip.url; 
		clip.autoBuffering = true;
		// until we sole the problem
		clip.urlResolvers = null;
		clip.onStart = function() {
			console.log("start");
		}

		$(videoPlayerWrapper).flowplayer(
			//"http://releases.flowplayer.org/swf/flowplayer-3.2.10.swf",
			flowbase + 'flowplayer-3.2.10.swf', 
			{
				clip: clip,
				plugins: plugins,
				screen: {
					 backgroundColor: '#ffffff'
				},
				canvas: {
					 backgroundColor: '#ffffff'
				},
				debug: false,
				log : {
					level  : 'info',
					filter : 'org.flowplayer.*'
				}
			}
		);
		videoPlayer = videoPlayerWrapper.flowplayer(0).ipad({ simulateiDevice: useVideoTag, controls: false });
		if (!videoPlayer.isLoaded()) {
			videoPlayer.load();
		}
		
		var offset = controls.find('.time').width();
		offset += controls.find('.play').width();
		controls.find('.track').width(videoPlayerWrapper.width() - offset - 35);
		videoPlayer.controls('controls');
	}

	return playHolder;
}

//
//	Silverlight
//
$.fn.media.xaml = function(el, opts) {
	if (!window.Sys || !window.Sys.Silverlight) {
		if ($.fn.media.xaml.warning) return;
		$.fn.media.xaml.warning = 1;
		alert('You must include the Silverlight.js script.');
		return;
	}

	var props = {
		width: opts.width,
		height: opts.height,
		background: opts.bgColor,
		inplaceInstallPrompt: opts.silverlight.inplaceInstallPrompt,
		isWindowless: opts.silverlight.isWindowless,
		framerate: opts.silverlight.framerate,
		version: opts.silverlight.version
	};
	var events = {
		onError: opts.silverlight.onError,
		onLoad: opts.silverlight.onLoad
	};

	var id1 = el.id ? (' id="'+el.id+'"') : '';
	var id2 = opts.id || 'AG' + counter++;
	// convert element to div
	var cls = opts.cls ? (' data-media="' + opts.cls + '"') : '';
	var $div = $('<div' + id1 + cls + '>');
	$(el).after($div).remove();

	Sys.Silverlight.createObjectEx({
		source: opts.src,
		initParams: opts.silverlight.initParams,
		userContext: opts.silverlight.userContext,
		id: id2,
		parentElement: $div[0],
		properties: props,
		events: events
	});

	if (opts.caption) $('<div>').appendTo($div).html(opts.caption);
	return $div;
};

//
// generate object/embed markup
//
function generate(el, opts, player) {
	var $el = $(el);
	var o = $.fn.media.defaults.players[player];

	if (player == 'iframe') {
		o = $('<iframe' + ' width="' + opts.width + '" height="' + opts.height + '" >');
		o.attr('src', opts.src);
		o.css('backgroundColor', opts.bgColor);
	}
	else if (player == 'img') {
		o = $('<img>');
		o.attr('src', opts.src);
		opts.width && o.attr('width', opts.width);
		opts.height && o.attr('height', opts.height);
		o.css('backgroundColor', opts.bgColor);
	}
	else if (lameIE) {
		var a = ['<object width="' + opts.width + '" height="' + opts.height + '" '];
		for (var key in opts.attrs)
			a.push(key + '="'+opts.attrs[key]+'" ');
		for (var key in o.ieAttrs || {}) {
			var v = o.ieAttrs[key];
			if (key == 'codebase' && window.location.protocol == 'https:')
				v = v.replace('http','https');
			a.push(key + '="'+v+'" ');
		}
		a.push('></ob'+'ject'+'>');
		var p = ['<param name="' + (o.oUrl || 'src') +'" value="' + opts.src + '">'];
		for (var key in opts.params)
			p.push('<param name="'+ key +'" value="' + opts.params[key] + '">');
		var o = document.createElement(a.join(''));
		for (var i=0; i < p.length; i++) {
			o.appendChild(document.createElement(p[i]));
		}
	}
	else if (opts.standards) {
		// Rewritten to be standards compliant by Richard Connamacher
		var a = ['<object type="' + o.mimetype +'" width="' + opts.width + '" height="' + opts.height +'"'];
		if (opts.src) a.push(' data="' + opts.src + '" ');
		if ($.browser.msie) {
			for (var key in o.ieAttrs || {}) {
				var v = o.ieAttrs[key];
				if (key == 'codebase' && window.location.protocol == 'https:')
					v = v.replace('http','https');
				a.push(key + '="'+v+'" ');
			}
		}
		a.push('>');
		a.push('<param name="' + (o.oUrl || 'src') +'" value="' + opts.src + '">');
		for (var key in opts.params) {
			if (key == 'wmode' && player != 'flash') // FF3/Quicktime borks on wmode
				continue;
			a.push('<param name="'+ key +'" value="' + opts.params[key] + '">');
		}
		// Alternate HTML
		a.push('<div><p><strong>'+o.title+' Required</strong></p><p>'+o.title+' is required to view this media. <a href="'+o.pluginspage+'">Download Here</a>.</p></div>');
		a.push('</ob'+'ject'+'>');
	}
	 else {
		var a = ['<embed width="' + opts.width + '" height="' + opts.height + '" style="display:block"'];
		if (opts.src) a.push(' src="' + opts.src + '" ');
		for (var key in opts.attrs)
			a.push(key + '="'+opts.attrs[key]+'" ');
		for (var key in o.eAttrs || {})
			a.push(key + '="'+o.eAttrs[key]+'" ');
		for (var key in opts.params) {
			if (key == 'wmode' && player != 'flash') // FF3/Quicktime borks on wmode
				continue;
			a.push(key + '="'+opts.params[key]+'" ');
		}
		a.push('></em'+'bed'+'>');
	}
	// convert element to div
	var id = el.id ? (' id="'+el.id+'"') : '';
	var cls = opts.cls ? (' data-media="' + opts.cls + '"') : '';
	var $div = $('<div' + id + cls + '>');
	$el.after($div).remove();
	(lameIE || player == 'iframe' || player == 'img') ? $div.append(o) : $div.html(a.join(''));
	if (opts.caption) $('<div>').appendTo($div).html(opts.caption);
	return $div;
};

})(jQuery);